import { Component, OnInit } from '@angular/core';
import {ApiService} from '../../service/api';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {TranslateService} from '@ngx-translate/core';
import {fadeIn} from '../../animation/fade-in';

@Component({
  selector: 'app-sensor-mgr',
  templateUrl: './sensor-mgr.component.html',
  styles: [`
    :host ::ng-deep .anticon-filter {
      left: 73px;
    }
    .btnPart {
      padding: 10px;
    }
  `],
  animations: [fadeIn]
})
export class SensorMgrComponent implements OnInit {

  data = [];
  query = {
    sensorName: '',
    sensorSN: ''
  };
  isLoading = false;
  isAllCheck = false;
  isIndeterminate = false;
  checkArray = [];
  page = 1;
  rows = 10;
  total = 125;
  listOfBind = [{text: '全部', value: 1}, {text: '已绑定', value: 2}, {text: '未绑定', value: 3}];
  selectedOne: any = {};
  isAddConV = false;
  isMultiAddConV = false;
  isBindCon = false;
  isMulti = false;
  addReq = {};
  bindReq = {};
  divideReq = {};

  constructor(private api: ApiService, private message: NzMessageService, private router: Router,
              private modalService: NzModalService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  next = (data) => {
    if (data && data.rows && data.rows.constructor === Array) {
      this.data = data.rows;
      this.total = data.total;
      this.initCheckArray(data.rows.length, false);
    } else if (data.code === 1) {
      this.message.success(data && data.message ? data.message : '操作成功');
    } else if (data.code === 0) {
      this.message.error(data && data.message ? data.message : '操作失败');
    } else {
      this.message.error(data && data.message ? data.message : '获取数据失败');
    }
    this.isLoading = false;
  };

  getData() {
    this.isLoading = true;
    this.api.loginlog.getAll(this.page, this.rows, ['', this.next]);
  }

  initCheckArray(n, b) {
    const obj = [];
    while (n > 0) {
      obj.push(b);
      n--;
    }
    this.checkArray = obj;
  }

  onSearch() {
  }

  onGetAll() {
  }

  checkAll(e) {
    this.isIndeterminate = false;
    this.initCheckArray(this.checkArray.length, e);
  }

  oneCheck(i) {
    const x = this.checkArray.filter(k => k).length;
    if (x === this.checkArray.length) {
      this.isIndeterminate = false;
      this.isAllCheck = true;
    } else if (x === 0) {
      this.isIndeterminate = false;
      this.isAllCheck = false;
    } else {
      this.isIndeterminate = true;
      this.isAllCheck = false;
    }
  }

  filter(a, b) {
    console.log(a, b);
  }

  getAllChecked() {
    const obj = [];
    this.data.map((one, index) => {
      if (this.checkArray[index]) {
        obj.push(index);
      }
    });
    return obj;
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  allDelete() {
    this.modalService.confirm({
      nzTitle  : '<i></i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteSelectedRecord') + '</b>',
      nzOnOk   : () => this.deleteAll()
    });
  }

  delete(one) {}

  deleteAll() {
    const obj = this.getAllChecked();
    console.log(obj);
  }

  allDivide() {
    this.isMulti = true;
  }

  allBind() {
    this.isMulti = true;
  }

  allUnbind() {
    this.isMulti = true;
  }

  allUpdate() {
    this.isMulti = true;
  }

  multiAdd() {
    this.isMulti = true;
  }

  toSee(e) {
    this.router.navigate(['/app/deviceCenter/sensorMgr/sensorDetail']);
  }

  add() {
    this.isMulti = false;
    this.isAddConV = true;
  }

  bind(one) {
    this.isMulti = false;
    this.selectedOne = one;
  }

  update(one) {
    this.isMulti = false;
    this.selectedOne = one;
  }

  cancel(v) {
    this[v] = false;
  }
  save(v) {
    this[v] = false;
  }

  toggleOn(one) {
    one.isLoading = true;
    setTimeout(() => {
      one.isOn = !one.isOn;
      one.isLoading = false;
    }, 2000);
  }
}
