import { HttpService } from './http';
import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { NzMessageService } from 'ng-zorro-antd';
import { environment } from '../../environments/environment';
import { TranslateService } from '@ngx-translate/core';

@Injectable()
export class ApiService {
  constructor(private http: HttpService, private router: Router,
              private message: NzMessageService, private translate: TranslateService) {
  }

  tokenLoseflag = 0;
  public url = environment.baseUrl;

  public imgUrl = environment.imgUrl; // 前端地址

  public loginlog = {
    getAll: (page, rows, data) => this.trans('get', '/system/loginlog/getAll?page=' + page + '&rows=' + rows, data),
    getByTime: (page, rows, data) => this.trans('post', '/system/loginlog/getByTime?page=' + page + '&rows=' + rows, data),
  };

  public login = {
    loginForToken: (data) => this.trans('post', '/system/login/loginForToken', data),
    logout: (data) => this.trans('get', '/system/login/logout', data),
  };

  public permission = {
    getAll: (data) => this.trans('get', '/system/permission/getAll', data),
    getPermissionByRoleNo: (data) => this.trans('post', '/system/permission/getPermissionByRoleNo', data),
  };

  public role = {
    addRole: (data) => this.trans('post', '/system/role/addRole', data),
    deleteRole: (data) => this.trans('post', '/system/role/deleteRole', data),
    getAll: (data) => this.trans('get', '/system/role/getAll', data),
    updateRole: (data) => this.trans('post', '/system/role/updateRole', data),
  };

  public user = {
    addUser: (data) => this.trans('post', '/system/user/addUser', data),
    deleteUser: (data) => this.trans('post', '/system/user/deleteUser', data),
    getAll: (data) => this.trans('get', '/system/user/getAll', data),
    getByUserNameForLike: (data) => this.trans('post', '/system/user/getByUserNameForLike', data),
    getSelfInfo: (data) => this.trans('get', '/system/user/getSelfInfo', data),
    updateSelfPassword: (data) => this.trans('post', '/system/user/updateSelfPassword', data),
    updateUser: (data) => this.trans('post', '/system/user/updateUser', data),
  };

  public area = {
    getAll: (data) => this.trans('get', '/system/getAll', data),
    getByCity: (data) => this.trans('post', '/system/getByCity', data),
  };

  public city = {
    getByProvince: (data) => this.trans('post', '/system/city/getByProvince', data),
  };

  public company = {
    addCompany: (data) => this.trans('post', '/system/company/addCompany', data),
    delCompany: (data) => this.trans('post', '/system/company/delCompany', data),
    getAll: (data) => this.trans('get', '/system/company/getAll', data),
    updateCompany: (data) => this.trans('post', '/system/company/updateCompany', data),
    updateCompanyPermission: (data) => this.trans('post', '/system/company/updateCompanyPermission', data),
  };

  public province = {
    getAll: (data) => this.trans('get', '/system/province/getAll', data),
  };

  private trans(type, addr, data) {
    this.sendHttpReq(type, addr, data[0], data[1], data[2], data[3]);
  }

  private sendHttpReq(type, addr, reqB, next, error, complete) {
    let nextFunc;
    if (addr === '/login/dologin') {
      nextFunc = (data: any) => {
        next(data);
      };
    } else {
      nextFunc = (data: any) => {
        if (this.http.handleToken(data)) {
          next(data);
        } else {
          if (!this.tokenLoseflag) {
            this.message.error(this.translate.instant('loginOutValidityTips'));
            this.http.toLoginPage(2000);
            this.tokenLoseflag = 1;
            setTimeout(() => {
              this.tokenLoseflag = 0;
            }, 5000);
          }
        }
      };
    }
    if (!error) {
      error = (err) => {
        let data;
        if (err && err.error && err.error.status) {
          if (err.error.status === 401) {
            data = {code: 0, message: this.translate.instant('noLoginTips')};
            this.router.navigate(['/extra/login']);
          } else {
            data = {code: 0, message: this.translate.instant('wrongServerWithCode') + err.error.status};
          }
        } else {
          data = {code: 0, message: this.translate.instant('wrongServer')};
        }
        next(data);
      };
    }
    if (type === 'get') {
      this.http.get(this.url + addr, nextFunc, error, complete);
    } else {
      this.http.post(this.url + addr, reqB, nextFunc, error, complete);
    }
  }
}
