import { Injectable } from '@angular/core';
import { NzMessageService } from 'ng-zorro-antd';
import { isUndefined } from 'util';
import { TranslateService } from '@ngx-translate/core';

@Injectable()
export class CheckService {
  constructor( private message: NzMessageService, private translate: TranslateService) {}

  formCheck(data, req) {
    const fNum = req.field.length;
    const fieldStr = '-' + req.field.join('-') + '-';
    const field = req.field.filter((item) => data[item] !== null && !isUndefined(data[item])).length;
    if (field !== fNum) {
      this.message.warning(this.translate.instant('pleaseFillAll'));
      return false;
    }
    const tNum = req.time ? req.time.length : 0;
    const time = req.time ? req.time.filter((item) => this.checkTime(fieldStr, data, item)).length : 0;
    if (time !== tNum) {
      this.message.warning(this.translate.instant('wrongTime'));
      return false;
    }
    const telNum = req.tel ? req.tel.length : 0;
    const tel = req.tel ? req.tel.filter((item) => this.checkTel(fieldStr, data, item)).length : 0;
    if (tel !== telNum) {
      this.message.warning(this.translate.instant('wrongTel'));
      return false;
    }
    const mNum = req.money ? req.money.length : 0;
    const money = req.money ? req.money.filter((item) => this.checkMoney(fieldStr, data, item)).length : 0;
    if (money !== mNum) {
      this.message.warning(this.translate.instant('wrongAmount'));
      return false;
    }
    const nNum = req.num ? req.num.length : 0;
    const num = req.num ? req.num.filter((item) => this.checkNum(fieldStr, data, item)).length : 0;
    if (num !== nNum) {
      this.message.warning(this.translate.instant('wrongNum'));
      return false;
    }

    const f2Num = req.float2 ? req.float2.length : 0;
    const float2 = req.float2 ? req.float2.filter((item) => this.checkFloat2(fieldStr, data, item)).length : 0;
    if (float2 !== f2Num) {
      this.message.warning(this.translate.instant('wrongNum'));
      return false;
    }
    return true;
  }

  private checkTime(fieldStr, data, time) {
    if ((data[time] === '' || isUndefined(data[time]) || data[time] === null) && fieldStr.indexOf('-' + time + '-') > -1) {
      return true;
    }
    if (data[time] && new Date(data[time]).getTime() > 0 && new Date(data[time]).getTime().toString().length === 13) {
      return true;
    } else {
      return false;
    }
  }

  private checkTel(fieldStr, data, tel) {
    if ((data[tel] === '' || isUndefined(data[tel]) || data[tel] === null) && fieldStr.indexOf('-' + tel + '-') > -1) {
      return true;
    }
    const reg = new RegExp( '^1\\d{10}$');
    if (data[tel].length !== 11 || !reg.test(data[tel])) {
      return false;
    } else {
      return true;
    }
  }

  private checkMoney(fieldStr, data, money) {
    if ((data[money] === '' || isUndefined(data[money]) || data[money] === null) && fieldStr.indexOf('-' + money + '-') > -1) {
      return true;
    }
    if (parseFloat(data[money]).toFixed(2) === data[money] && parseInt(data[money], 10).toString().length < 8) {
      return true;
    } else {
      return false;
    }
  }

  private checkNum(fieldStr, data, num) {
    if ((data[num] === '' || isUndefined(data[num]) || data[num] === null) && fieldStr.indexOf('-' + num + '-') > -1) {
      return true;
    }
    const reg = new RegExp( '^[0-9]*$');
    if (reg.test(data[num])) {
      return true;
    } else {
      return false;
    }
  }

  private checkFloat2(fieldStr, data, float2) {
    if ((data[float2] === '' || isUndefined(data[float2]) || data[float2] === null) && fieldStr.indexOf('-' + float2 + '-') > -1) {
      return true;
    }
    if ( parseFloat(data[float2]).toFixed(2).toString() === data[float2]) {
      return true;
    } else {
      return false;
    }
  }
}
